==> open-next-cdk-0.0.6-sources.jar: io/dataspray/opennextcdk/ImageOptimizationLambda.java <==
package io.dataspray.opennextcdk;

/**
 * This lambda handles image optimization.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.80.0 (build bce6a1d)", date = "2023-07-30T03:46:44.217Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = io.dataspray.opennextcdk.$Module.class, fqn = "open-next-cdk.ImageOptimizationLambda")
public class ImageOptimizationLambda extends software.amazon.awscdk.services.lambda.Function {

    protected ImageOptimizationLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ImageOptimizationLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ImageOptimizationLambda(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull io.dataspray.opennextcdk.ImageOptimizationProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket getBucket() {
        return software.amazon.jsii.Kernel.get(this, "bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.IBucket.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setBucket(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket value) {
        software.amazon.jsii.Kernel.set(this, "bucket", java.util.Objects.requireNonNull(value, "bucket is required"));
    }

    /**
     * A fluent builder for {@link io.dataspray.opennextcdk.ImageOptimizationLambda}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<io.dataspray.opennextcdk.ImageOptimizationLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final io.dataspray.opennextcdk.ImageOptimizationProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new io.dataspray.opennextcdk.ImageOptimizationProps.Builder();
        }

        /**
         * Optional value used to install NextJS node dependencies.
         * <p>
         * It defaults to 'npx --yes open-next&#64;latest build'
         * <p>
         * @return {@code this}
         * @param buildCommand Optional value used to install NextJS node dependencies. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder buildCommand(final java.lang.String buildCommand) {
            this.props.buildCommand(buildCommand);
            return this;
        }

        /**
         * The directory to execute `npm run build` from.
         * <p>
         * By default, it is <code>nextjsPath</code>.
         * Can be overridden, particularly useful for monorepos where <code>build</code> is expected to run
         * at the root of the project.
         * <p>
         * @return {@code this}
         * @param buildPath The directory to execute `npm run build` from. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder buildPath(final java.lang.String buildPath) {
            this.props.buildPath(buildPath);
            return this;
        }

        /**
         * 0 - no compression, fastest 9 - maximum compression, slowest.
         * <p>
         * Default: 1
         * <p>
         * @return {@code this}
         * @param compressionLevel 0 - no compression, fastest 9 - maximum compression, slowest. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder compressionLevel(final java.lang.Number compressionLevel) {
            this.props.compressionLevel(compressionLevel);
            return this;
        }

        /**
         * Custom environment variables to pass to the NextJS build and runtime.
         * <p>
         * @return {@code this}
         * @param environment Custom environment variables to pass to the NextJS build and runtime. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder environment(final java.util.Map<java.lang.String, java.lang.String> environment) {
            this.props.environment(environment);
            return this;
        }

        /**
         * (deprecated) Used in conjunction with nextJsPath to skip building NextJS app and assume .open-next folder already exists. Useful when using `next dev` for local development.
         * <p>
         * @return {@code this}
         * @deprecated use `openNextPath` instead
         * @param isPlaceholder Used in conjunction with nextJsPath to skip building NextJS app and assume .open-next folder already exists. Useful when using `next dev` for local development. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder isPlaceholder(final java.lang.Boolean isPlaceholder) {
            this.props.isPlaceholder(isPlaceholder);
            return this;
        }

        /**
         * (deprecated) Relative path to the directory where the NextJS project is located.
         * <p>
         * Can be the root of your project (<code>.</code>) or a subdirectory (<code>packages/web</code>).
         * <p>
         * One of <code>openNextPath</code>, <code>nextJsPath</code> or <code>nextjsPath</code> must be supplied.
         * <p>
         * @return {@code this}
         * @deprecated use `nextJsPath` instead
         * @param nextjsPath Relative path to the directory where the NextJS project is located. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder nextjsPath(final java.lang.String nextjsPath) {
            this.props.nextjsPath(nextjsPath);
            return this;
        }

        /**
         * Relative path to the directory where the NextJS project is located.
         * <p>
         * Can be the root of your project (<code>.</code>) or a subdirectory (<code>packages/web</code>).
         * <p>
         * One of <code>openNextPath</code> or <code>nextJsPath</code> must be supplied.
         * <p>
         * @return {@code this}
         * @param nextJsPath Relative path to the directory where the NextJS project is located. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nextJsPath(final java.lang.String nextJsPath) {
            this.props.nextJsPath(nextJsPath);
            return this;
        }

        /**
         * Optional value for NODE_ENV during build and runtime.
         * <p>
         * @return {@code this}
         * @param nodeEnv Optional value for NODE_ENV during build and runtime. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nodeEnv(final java.lang.String nodeEnv) {
            this.props.nodeEnv(nodeEnv);
            return this;
        }

        /**
         * Relative path to the OpenNext package named `.open-next` by default.
         * <p>
         * One of <code>openNextPath</code> or <code>nextJsPath</code> must be supplied.
         * <p>
         * @return {@code this}
         * @param openNextPath Relative path to the OpenNext package named `.open-next` by default. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder openNextPath(final java.lang.String openNextPath) {
            this.props.openNextPath(openNextPath);
            return this;
        }

        /**
         * Less build output.
         * <p>
         * @return {@code this}
         * @param quiet Less build output. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder quiet(final java.lang.Boolean quiet) {
            this.props.quiet(quiet);
            return this;
        }

        /**
         * Optional arn for the sharp lambda layer.
         * <p>
         * If omitted, the layer will be created.
         * <p>
         * @return {@code this}
         * @param sharpLayerArn Optional arn for the sharp lambda layer. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sharpLayerArn(final java.lang.String sharpLayerArn) {
            this.props.sharpLayerArn(sharpLayerArn);
            return this;
        }

        /**
         * Directory to store temporary build files in.
         * <p>
         * Defaults to os.tmpdir().
         * <p>
         * @return {@code this}
         * @param tempBuildDir Directory to store temporary build files in. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tempBuildDir(final java.lang.String tempBuildDir) {
            this.props.tempBuildDir(tempBuildDir);
            return this;
        }

        /**
         * The S3 bucket holding application images.
         * <p>
         * @return {@code this}
         * @param bucket The S3 bucket holding application images. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder bucket(final software.amazon.awscdk.services.s3.IBucket bucket) {
            this.props.bucket(bucket);
            return this;
        }

        /**
         * The `NextjsBuild` instance representing the built Nextjs application.
         * <p>
         * @return {@code this}
         * @param nextBuild The `NextjsBuild` instance representing the built Nextjs application. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nextBuild(final io.dataspray.opennextcdk.NextjsBuild nextBuild) {
            this.props.nextBuild(nextBuild);
            return this;
        }

        /**
         * Override function properties.
         * <p>
         * @return {@code this}
         * @param lambdaOptions Override function properties. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder lambdaOptions(final software.amazon.awscdk.services.lambda.FunctionOptions lambdaOptions) {
            this.props.lambdaOptions(lambdaOptions);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.dataspray.opennextcdk.ImageOptimizationLambda}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public io.dataspray.opennextcdk.ImageOptimizationLambda build() {
            return new io.dataspray.opennextcdk.ImageOptimizationLambda(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> open-next-cdk-0.0.9-sources.jar: io/dataspray/opennextcdk/ImageOptimizationLambda.java <==
package io.dataspray.opennextcdk;

/**
 * This lambda handles image optimization.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.86.0 (build bc5c93a)", date = "2023-09-25T15:41:32.891Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = io.dataspray.opennextcdk.$Module.class, fqn = "open-next-cdk.ImageOptimizationLambda")
public class ImageOptimizationLambda extends software.amazon.awscdk.services.lambda.Function {

    protected ImageOptimizationLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ImageOptimizationLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ImageOptimizationLambda(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull io.dataspray.opennextcdk.ImageOptimizationProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket getBucket() {
        return software.amazon.jsii.Kernel.get(this, "bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.IBucket.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setBucket(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket value) {
        software.amazon.jsii.Kernel.set(this, "bucket", java.util.Objects.requireNonNull(value, "bucket is required"));
    }

    /**
     * A fluent builder for {@link io.dataspray.opennextcdk.ImageOptimizationLambda}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<io.dataspray.opennextcdk.ImageOptimizationLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final io.dataspray.opennextcdk.ImageOptimizationProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new io.dataspray.opennextcdk.ImageOptimizationProps.Builder();
        }

        /**
         * Optional value used to install NextJS node dependencies.
         * <p>
         * It defaults to 'npx --yes open-next&#64;1 build'
         * <p>
         * @return {@code this}
         * @param buildCommand Optional value used to install NextJS node dependencies. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder buildCommand(final java.lang.String buildCommand) {
            this.props.buildCommand(buildCommand);
            return this;
        }

        /**
         * The directory to execute <code>npm run build</code> from.
         * <p>
         * By default, it is <code>nextjsPath</code>.
         * Can be overridden, particularly useful for monorepos where <code>build</code> is expected to run
         * at the root of the project.
         * <p>
         * @return {@code this}
         * @param buildPath The directory to execute <code>npm run build</code> from. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder buildPath(final java.lang.String buildPath) {
            this.props.buildPath(buildPath);
            return this;
        }

        /**
         * 0 - no compression, fastest 9 - maximum compression, slowest.
         * <p>
         * Default: 1
         * <p>
         * @return {@code this}
         * @param compressionLevel 0 - no compression, fastest 9 - maximum compression, slowest. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder compressionLevel(final java.lang.Number compressionLevel) {
            this.props.compressionLevel(compressionLevel);
            return this;
        }

        /**
         * Custom environment variables to pass to the NextJS build and runtime.
         * <p>
         * @return {@code this}
         * @param environment Custom environment variables to pass to the NextJS build and runtime. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder environment(final java.util.Map<java.lang.String, java.lang.String> environment) {
            this.props.environment(environment);
            return this;
        }

        /**
         * (deprecated) Used in conjunction with nextJsPath to skip building NextJS app and assume .open-next folder already exists. Useful when using <code>next dev</code> for local development.
         * <p>
         * @return {@code this}
         * @deprecated use <code>openNextPath</code> instead
         * @param isPlaceholder Used in conjunction with nextJsPath to skip building NextJS app and assume .open-next folder already exists. Useful when using <code>next dev</code> for local development. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder isPlaceholder(final java.lang.Boolean isPlaceholder) {
            this.props.isPlaceholder(isPlaceholder);
            return this;
        }

        /**
         * (deprecated) Relative path to the directory where the NextJS project is located.
         * <p>
         * Can be the root of your project (<code>.</code>) or a subdirectory (<code>packages/web</code>).
         * <p>
         * One of <code>openNextPath</code>, <code>nextJsPath</code> or <code>nextjsPath</code> must be supplied.
         * <p>
         * @return {@code this}
         * @deprecated use <code>nextJsPath</code> instead
         * @param nextjsPath Relative path to the directory where the NextJS project is located. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder nextjsPath(final java.lang.String nextjsPath) {
            this.props.nextjsPath(nextjsPath);
            return this;
        }

        /**
         * Relative path to the directory where the NextJS project is located.
         * <p>
         * Can be the root of your project (<code>.</code>) or a subdirectory (<code>packages/web</code>).
         * <p>
         * One of <code>openNextPath</code> or <code>nextJsPath</code> must be supplied.
         * <p>
         * @return {@code this}
         * @param nextJsPath Relative path to the directory where the NextJS project is located. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nextJsPath(final java.lang.String nextJsPath) {
            this.props.nextJsPath(nextJsPath);
            return this;
        }

        /**
         * Optional value for NODE_ENV during build and runtime.
         * <p>
         * @return {@code this}
         * @param nodeEnv Optional value for NODE_ENV during build and runtime. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nodeEnv(final java.lang.String nodeEnv) {
            this.props.nodeEnv(nodeEnv);
            return this;
        }

        /**
         * Relative path to the OpenNext package named <code>.open-next</code> by default.
         * <p>
         * One of <code>openNextPath</code> or <code>nextJsPath</code> must be supplied.
         * <p>
         * @return {@code this}
         * @param openNextPath Relative path to the OpenNext package named <code>.open-next</code> by default. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder openNextPath(final java.lang.String openNextPath) {
            this.props.openNextPath(openNextPath);
            return this;
        }

        /**
         * Less build output.
         * <p>
         * @return {@code this}
         * @param quiet Less build output. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder quiet(final java.lang.Boolean quiet) {
            this.props.quiet(quiet);
            return this;
        }

        /**
         * Optional arn for the sharp lambda layer.
         * <p>
         * If omitted, the layer will be created.
         * <p>
         * @return {@code this}
         * @param sharpLayerArn Optional arn for the sharp lambda layer. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sharpLayerArn(final java.lang.String sharpLayerArn) {
            this.props.sharpLayerArn(sharpLayerArn);
            return this;
        }

        /**
         * Directory to store temporary build files in.
         * <p>
         * Defaults to os.tmpdir().
         * <p>
         * @return {@code this}
         * @param tempBuildDir Directory to store temporary build files in. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tempBuildDir(final java.lang.String tempBuildDir) {
            this.props.tempBuildDir(tempBuildDir);
            return this;
        }

        /**
         * The S3 bucket holding application images.
         * <p>
         * @return {@code this}
         * @param bucket The S3 bucket holding application images. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder bucket(final software.amazon.awscdk.services.s3.IBucket bucket) {
            this.props.bucket(bucket);
            return this;
        }

        /**
         * The <code>NextjsBuild</code> instance representing the built Nextjs application.
         * <p>
         * @return {@code this}
         * @param nextBuild The <code>NextjsBuild</code> instance representing the built Nextjs application. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder nextBuild(final io.dataspray.opennextcdk.NextjsBuild nextBuild) {
            this.props.nextBuild(nextBuild);
            return this;
        }

        /**
         * Override function properties.
         * <p>
         * @return {@code this}
         * @param lambdaOptions Override function properties. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder lambdaOptions(final software.amazon.awscdk.services.lambda.FunctionOptions lambdaOptions) {
            this.props.lambdaOptions(lambdaOptions);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.dataspray.opennextcdk.ImageOptimizationLambda}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public io.dataspray.opennextcdk.ImageOptimizationLambda build() {
            return new io.dataspray.opennextcdk.ImageOptimizationLambda(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
